@@ -2,7 +2,7 @@
 # @Author: Antoine Tavant
 # @Date:   2022-01-21 13:21:38
 # @Last Modified by:   Antoine Tavant
-# @Last Modified time: 2022-01-21 13:26:46
+# @Last Modified time: 2022-01-26 14:25:54
 """Top-level package for pythermica."""
 
 __author__ = """Antoine Tavant"""
@@ -10,4 +10,8 @@ __email__ = 'antoine.tavant@lpp.polytechnique.fr'
 __version__ = '0.1.2'
 
 from .pythermica import Thermica
+from .analyse_nwk import *
+from .plot_variables import *
+from .hdf5_process import *
+
 
